==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/tr.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Yüksek renk karşıtlıklı tema",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Yüksek renk karşıtlıklı tema gezinmeyi kolaylaştırır. Görsel kalite azalır ancak netlik artar.",
    "Dark theme" : "Koyu tema",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Koyu tema genel parlaklık ve canlılığı zayıflatarak göz yorgunluğunu azaltır. Bu tema henüz geliştirme aşamasında olduğundan karşılaşabileceğiniz sorunları bize iletmenizi rica ediyoruz.",
    "Dyslexia font" : "Disleksik yazı türü",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic, disleksi nedeniyle sık karşılaşılan sorunları aşmak için geliştirilmiş ücretsiz bir yazı türüdür.",
    "Accessibility" : "Erişilebilirlik",
    "Accessibility options for nextcloud" : "Nextcloud erişebilirlik ayarları",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Nextcloud kullanımınızı kolaylaştıracak çeşitli erişebilirlik seçenekleri sunar",
    "Web Content Accessibility Guidelines" : "Web İçeriği Erişebilirlik Kılavuzları",
    "our issue tracker" : "sorun kayıt sistemimiz",
    "our design team" : "geliştirme ekibimiz",
    "Enable" : "Etkinleştir",
    "Dark theme (beta)" : "Koyu tema (beta)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic, disleksi nedeniyle sık karşılaşılan sorunları aşmak için geliştirilmiş ücretsiz bir yazı türüdür. Bu yazı türü Abelardo Gonzalez tarafından oluşturulmuş ve açık kaynak lisansı ile yayınlanmıştır.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Nextcloud kullanımınızı kolaylaştıracak çeşitli erişebilirlik seçenekleri sunar",
    "Themes" : "Temalar",
    "Fonts" : "Yazı Türleri",
    "enabled" : "etkin"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-18.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/tr.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Koyu tema",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Koyu tema genel parlaklık ve canlılığı zayıflatarak göz yorgunluğunu azaltır. Bu tema henüz geliştirme aşamasında olduğundan karşılaşabileceğiniz sorunları bize iletmenizi rica ediyoruz.",
    "High contrast mode" : "Yüksek renk karşıtlığı kipi",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Yüksek renk karşıtlığı kipi gezinmeyi kolaylaştırır. Görsel kalite azalır ancak netlik artar.",
    "Dyslexia font" : "Disleksik yazı türü",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic, disleksi nedeniyle sık karşılaşılan sorunları aşmak için geliştirilmiş ücretsiz bir yazı türüdür.",
    "Accessibility" : "Erişilebilirlik",
    "Accessibility options for nextcloud" : "Nextcloud erişebilirlik ayarları",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Nextcloud kullanımınızı kolaylaştıracak çeşitli erişebilirlik seçenekleri sunar",
    "Web Content Accessibility Guidelines" : "Web İçeriği Erişebilirlik Kılavuzları",
    "our issue tracker" : "sorun kayıt sistemimiz",
    "our design team" : "geliştirme ekibimiz",
    "Enable" : "Etkinleştir",
    "High contrast theme" : "Yüksek renk karşıtlıklı tema",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Yüksek renk karşıtlıklı tema gezinmeyi kolaylaştırır. Görsel kalite azalır ancak netlik artar.",
    "Dark theme (beta)" : "Koyu tema (beta)"
},
"nplurals=2; plural=(n > 1);");
